@@ -7,9 +7,7 @@
 extern "C" {
 #endif
 
-#define PILOT_LINK_VERSION 0
-#define PILOT_LINK_MAJOR 8
-#define PILOT_LINK_MINOR 7
+#include "pi-version.h"
 
 #define PI_AF_SLP 0x0051        /* arbitrary, for completeness, just in case */
 #define PI_AF_INETSLP 0x0054    
@@ -28,10 +26,7 @@ extern "C" {
 #define PI_PilotSocketDebugger  0
 #define PI_PilotSocketRemoteUI  2
 
-struct pi_sockaddr {
-  unsigned short pi_family;
-  char pi_device[12];
-};
+#include "pi-sockaddr.h"
 
 struct pi_skb;
 
